# Security Policy

## Supported Versions

This project is currently pre-1.0 and evolves quickly. Only the latest release is considered for security fixes.

## Reporting a Vulnerability

Please do not open a public GitHub issue for security-sensitive reports.

Use GitHub Security Advisories instead:

- Go to the repository page
- Click **Security**
- Click **Report a vulnerability**

If you are unable to use GitHub advisories, contact the repository owner via their GitHub profile.

## Abuse / Safety

This is an unofficial WhatsApp Web client implementation. Be careful with features that could facilitate abuse
(spam, unsolicited automation, scraping). Maintainers may decline changes that increase abuse risk.

